#include "qgebsimpletablewidget.h"
#include <QAction>
#include <QHeaderView>
#include <QFileDialog>
#include <QFile>
#include "qgebprint.h"

QgebSimpleTableWidget::QgebSimpleTableWidget(QWidget *parent) :
    QTableWidget(parent)
{
    setContentMenu();
}


/*
  Создание контекстного меню
*/
void QgebSimpleTableWidget::setContentMenu()
{
    QAction * printPrevAction = new QAction(tr("Печать c предварительным просмотром"), this);
    printPrevAction->setStatusTip(tr("Печать таблицы c предварительным просмотром"));
    connect (printPrevAction, SIGNAL(triggered()), this, SLOT(printPrevSlot()));
    QAction * printAction = new QAction(tr("Прямая печать таблицы"), this);
    printAction->setStatusTip(tr("Прямая печать таблицы"));
    connect (printAction, SIGNAL(triggered()), this, SLOT(printSlot()));
#ifndef QT_NO_PRINTDIALOG
    horizontalHeader()->addAction(printAction);
    horizontalHeader()->addAction(printPrevAction);
#endif
    horizontalHeader()->setContextMenuPolicy(Qt::ActionsContextMenu);
}



/*
  Формирование таблицы в виде HTML документа
*/
void QgebSimpleTableWidget::createHtmlDocument()
{
    out << "<html>\n";
    out << "<head>\n";
    out << "<meta http-equiv='Content-Type' content='text/html; charset=UTF-8' />\n";
    out << tr("<title>Простая таблица</title>\n");
    out << "</head>\n";
    out << "<body>\n";
    out << "<table border='1'>\n";

    // заголовок таблицы
    if ( !verticalHeader()->isHidden() )
        out << "<th width='" + QString::number(verticalHeader()->width()) + "'>&nbsp</th>\n";
    for (int col=0; col<columnCount(); ++col)
        out << "<th width='" + QString::number(columnWidth(col)) + "'>" + tr(horizontalHeaderItem(col)->text().toAscii()) + "</th>\n";
    // тело таблицы
    for (int row=0; row<rowCount(); ++row)
    {
        out << "<tr>\n";
        //если установлен вертикальный заголовок, то имитируем его
        if ( !verticalHeader()->isHidden() )
        {
            QTableWidgetItem * item = this->verticalHeaderItem(row);
            if (item == 0 )
                out << "<td>" + QString::number(row+1) + "</td>\n";
            else
                out << "<td>" + tr(verticalHeaderItem(row)->text().toAscii()) + "</td>\n";
        }
        for (int col=0; col<columnCount(); ++col)
            out << "<td " + getAlign(row, col) + ">" + item(row, col)->text().replace("\n", "<br/") + "</td>\n";
        out << "</tr>\n";
    }
    out << "</table>\n";
    out << "</body>\n";
    out << "</html>\n";
}


QString QgebSimpleTableWidget::getAlign(int row, int col)
{
    QString s1, s2;
    int align = item(row, col)->textAlignment(); //значение выравнивания в ячейке
    align = align & 15;  //выделяем горизонтальное выравнивание
    switch (align)
    {
    case Qt::AlignHCenter:
        s1 = "center";
        break;
    case Qt::AlignLeft:
        s1 = "left";
        break;
    case Qt::AlignRight:
        s1 = "right";
        break;
    case Qt::AlignJustify:
        s1 = "justify";
        break;
    default:
        s1  = "center";
        break;
    }
    s1 = "align='" + s1 + "'";
    align = item(row, col)->textAlignment(); //значение выравнивания в ячейке
    align = align & 240;  //выделяем вертикальное выравнивание
    switch (align)
    {
    case Qt::AlignTop:
        s2 = "top";
        break;
    case Qt::AlignBottom:
        s2 = "bottom";
        break;
    case Qt::AlignVCenter:
        s2 = "middle";
        break;
    default:
        s2  = "middle";
        break;
    }
    s2 = "valign='" + s2 + "'";
    return s1 + " " + s2;
}


/*
  Печать таблицы с предварительным просмотром
*/
void QgebSimpleTableWidget::printPrevSlot()
{
#ifndef QT_NO_PRINTDIALOG
    QString s;
    //устанавливаем строку как буфер в текстовом потоке
    out.setString(&s, QIODevice::ReadWrite);
    createHtmlDocument();   //преобразовываем таблицу в HTML  и выводим ее в указанный поток
    QgebPrint * print = new QgebPrint();
    print->printPreview(s);
    delete print;
 #endif
}


/*
  Прямая печать таблицы (без предварительного просмотра)
*/
void QgebSimpleTableWidget::printSlot()
{
#ifndef QT_NO_PRINTDIALOG
    QString s;
    //устанавливаем строку как буфер в текстовом потоке
    out.setString(&s, QIODevice::ReadWrite);
    createHtmlDocument();   //преобразовываем таблицу в HTML  и выводим ее в указанный поток
    QgebPrint * print = new QgebPrint();
    print->print(s);
 //   delete print;
 #endif
}


